@@ -11,11 +11,9 @@
 #include "akonadi_indexer_agent_debug.h"
 
 #include <KCalendarCore/Attendee>
-#include <KCalendarCore/Event>
 
 CalendarIndexer::CalendarIndexer(const QString &path)
     : AbstractIndexer()
-    , m_db(nullptr)
 {
     try {
         m_db = new Akonadi::Search::XapianDatabase(path, true);
@@ -31,10 +29,8 @@ CalendarIndexer::CalendarIndexer(const QString &path)
 
 CalendarIndexer::~CalendarIndexer()
 {
-    if (m_db) {
-        m_db->commit();
-        delete m_db;
-    }
+    commit();
+    delete m_db;
 }
 
 QStringList CalendarIndexer::mimeTypes() const
@@ -60,9 +56,16 @@ void CalendarIndexer::index(const Akonadi::Item &item)
 
 void CalendarIndexer::commit()
 {
-    if (m_db) {
-        m_db->commit();
+    if (!m_db) {
+        return;
     }
+
+    try {
+        m_db->commit();
+    } catch (const Xapian::Error &err) {
+        qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
+    }
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Xapian Committed";
 }
 
 void CalendarIndexer::remove(const Akonadi::Item &item)
@@ -83,7 +86,7 @@ void CalendarIndexer::remove(const Akonadi::Collection &collection)
         return;
     }
     try {
-        Xapian::Query query('C' + QString::number(collection.id()).toStdString());
+        const Xapian::Query query('C' + QString::number(collection.id()).toStdString());
         Xapian::Enquire enquire(*(m_db->db()));
         enquire.set_query(query);
 
@@ -125,7 +128,7 @@ void CalendarIndexer::indexEventItem(const Akonadi::Item &item, const KCalendarC
     doc.indexText(event->organizer().email(), QStringLiteral("O"));
     doc.indexText(event->summary(), QStringLiteral("S"));
     doc.indexText(event->location(), QStringLiteral("L"));
-    KCalendarCore::Attendee::List attendees = event->attendees();
+    const KCalendarCore::Attendee::List attendees = event->attendees();
     KCalendarCore::Attendee::List::ConstIterator it;
     KCalendarCore::Attendee::List::ConstIterator end(attendees.constEnd());
     for (it = attendees.constBegin(); it != end; ++it) {
