@@ -16,12 +16,9 @@
 
 EmailIndexer::EmailIndexer(const QString &path, const QString &contactDbPath)
     : AbstractIndexer()
-    , m_doc(nullptr)
-    , m_termGen(nullptr)
-    , m_contactDb(nullptr)
 {
     try {
-        m_db = new Xapian::WritableDatabase(path.toUtf8().constData(), Xapian::DB_CREATE_OR_OPEN);
+        m_db = new Xapian::WritableDatabase(path.toStdString(), Xapian::DB_CREATE_OR_OPEN);
     } catch (const Xapian::DatabaseCorruptError &err) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Database Corrupted - What did you do?";
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
@@ -32,7 +29,7 @@ EmailIndexer::EmailIndexer(const QString &path, const QString &contactDbPath)
     }
 
     try {
-        m_contactDb = new Xapian::WritableDatabase(contactDbPath.toUtf8().constData(), Xapian::DB_CREATE_OR_OPEN);
+        m_contactDb = new Xapian::WritableDatabase(contactDbPath.toStdString(), Xapian::DB_CREATE_OR_OPEN);
     } catch (const Xapian::DatabaseCorruptError &err) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Database Corrupted - What did you do?";
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
@@ -45,15 +42,9 @@ EmailIndexer::EmailIndexer(const QString &path, const QString &contactDbPath)
 
 EmailIndexer::~EmailIndexer()
 {
-    if (m_db) {
-        m_db->commit();
-        delete m_db;
-    }
-
-    if (m_contactDb) {
-        m_contactDb->commit();
-        delete m_contactDb;
-    }
+    commit();
+    delete m_db;
+    delete m_contactDb;
 }
 
 QStringList EmailIndexer::mimeTypes() const
@@ -95,8 +86,8 @@ void EmailIndexer::index(const Akonadi::Item &item)
     Q_ASSERT_X(item.parentCollection().isValid(), "Akonadi::Search::EmailIndexer::index",
                "Item does not have a valid parent collection");
 
-    Akonadi::Collection::Id colId = item.parentCollection().id();
-    QByteArray term = 'C' + QByteArray::number(colId);
+    const Akonadi::Collection::Id colId = item.parentCollection().id();
+    const QByteArray term = 'C' + QByteArray::number(colId);
     m_doc->add_boolean_term(term.data());
 
     m_db->replace_document(item.id(), *m_doc);
@@ -112,7 +103,7 @@ void EmailIndexer::index(const Akonadi::Item &item)
 void EmailIndexer::insert(const QByteArray &key, KMime::Headers::Base *unstructured)
 {
     if (unstructured) {
-        m_termGen->index_text_without_positions(unstructured->asUnicodeString().toUtf8().constData(), 1, key.data());
+        m_termGen->index_text_without_positions(unstructured->asUnicodeString().toStdString(), 1, key.data());
     }
 }
 
@@ -150,7 +141,7 @@ void EmailIndexer::insert(const QByteArray &key, const KMime::Types::Mailbox::Li
         return;
     }
     for (const KMime::Types::Mailbox &mbox : list) {
-        std::string name(mbox.name().toUtf8().constData());
+        const std::string name(mbox.name().toStdString());
         m_termGen->index_text_without_positions(name, 1, key.data());
         m_termGen->index_text_without_positions(name, 1);
         m_termGen->index_text_without_positions(mbox.address().data(), 1, key.data());
@@ -169,7 +160,7 @@ void EmailIndexer::insert(const QByteArray &key, const KMime::Types::Mailbox::Li
             continue;
         } catch (const Xapian::DocNotFoundError &) {
             Xapian::Document doc;
-            std::string pretty(pa.toUtf8().constData());
+            const std::string pretty(pa.toStdString());
             doc.set_data(pretty);
 
             Xapian::TermGenerator termGen;
@@ -190,7 +181,7 @@ void EmailIndexer::process(const KMime::Message::Ptr &msg)
     // (Give the subject a higher priority)
     KMime::Headers::Subject *subject = msg->subject(false);
     if (subject) {
-        std::string str(subject->asUnicodeString().toUtf8().constData());
+        const std::string str(subject->asUnicodeString().toStdString());
         qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Indexing" << str.c_str();
         m_termGen->index_text_without_positions(str, 1, "SU");
         m_termGen->index_text_without_positions(str, 100);
@@ -226,7 +217,7 @@ void EmailIndexer::process(const KMime::Message::Ptr &msg)
 
     KMime::Content *mainBody = msg->mainBodyPart("text/plain");
     if (mainBody) {
-        const std::string text(mainBody->decodedText().toUtf8().constData());
+        const std::string text(mainBody->decodedText().toStdString());
         m_termGen->index_text_without_positions(text);
         m_termGen->index_text_without_positions(text, 1, "BO");
     } else {
@@ -257,7 +248,7 @@ void EmailIndexer::processPart(KMime::Content *content, KMime::Content *mainCont
             QTextDocument doc;
             doc.setHtml(content->decodedText());
 
-            const std::string text(doc.toPlainText().toUtf8().constData());
+            const std::string text(doc.toPlainText().toStdString());
             m_termGen->index_text_without_positions(text);
         }
     }
@@ -400,9 +391,20 @@ void EmailIndexer::move(Akonadi::Item::Id itemId, Akonadi::Collection::Id from,
 void EmailIndexer::commit()
 {
     if (m_db) {
-        m_db->commit();
+        try {
+            m_db->commit();
+        } catch (const Xapian::Error &err) {
+            qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
+        }
+        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Xapian Committed";
     }
+
     if (m_contactDb) {
-        m_contactDb->commit();
+        try {
+            m_contactDb->commit();
+        } catch (const Xapian::Error &err) {
+            qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
+        }
+        qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Xapian Committed";
     }
 }
