@@ -6,7 +6,6 @@
 
 #include "akonadisearchdebugwidget.h"
 #include "job/akonadisearchdebugsearchjob.h"
-#include "akonadisearchdebugsearchpathcombobox.h"
 #include "akonadisearchsyntaxhighlighter.h"
 #include <KLineEdit>
 #include <QPushButton>
@@ -21,9 +20,9 @@ using namespace Akonadi::Search;
 AkonadiSearchDebugWidget::AkonadiSearchDebugWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
-    QHBoxLayout *hbox = new QHBoxLayout;
+    auto *hbox = new QHBoxLayout;
     mainLayout->addLayout(hbox);
     QLabel *lab = new QLabel(QStringLiteral("Item identifier:"), this);
     hbox->addWidget(lab);
@@ -88,7 +87,7 @@ void AkonadiSearchDebugWidget::slotSearch()
     if (searchId.isEmpty()) {
         return;
     }
-    Akonadi::Search::AkonadiSearchDebugSearchJob *job = new Akonadi::Search::AkonadiSearchDebugSearchJob(this);
+    auto *job = new Akonadi::Search::AkonadiSearchDebugSearchJob(this);
     job->setAkonadiId(searchId);
     job->setSearchPath(mSearchPathComboBox->searchPath());
     connect(job, &Akonadi::Search::AkonadiSearchDebugSearchJob::result, this, &AkonadiSearchDebugWidget::slotResult);
