@@ -1,7 +1,7 @@
 /*
   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "../akonadisearchdebugdialog.h"
@@ -20,7 +20,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    Akonadi::Search::AkonadiSearchDebugDialog *dlg = new Akonadi::Search::AkonadiSearchDebugDialog();
+    auto *dlg = new Akonadi::Search::AkonadiSearchDebugDialog();
     dlg->resize(800, 600);
     dlg->show();
     app.exec();
