@@ -95,18 +95,18 @@ ResultIterator ContactQuery::exec()
     Xapian::Database db;
 
     try {
-        db = Xapian::Database(QFile::encodeName(dir).constData());
+        db = Xapian::Database(QFile::encodeName(dir).toStdString());
     } catch (const Xapian::DatabaseOpeningError &) {
-        qWarning() << "Xapian Database does not exist at " << dir;
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database does not exist at " << dir;
         return ResultIterator();
     } catch (const Xapian::DatabaseCorruptError &) {
-        qWarning() << "Xapian Database corrupted";
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Xapian Database corrupted";
         return ResultIterator();
     } catch (const Xapian::DatabaseError &e) {
-        qWarning() << "Failed to open Xapian database:" << QString::fromStdString(e.get_error_string());
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Failed to open Xapian database:" << QString::fromStdString(e.get_error_string());
         return ResultIterator();
     } catch (...) {
-        qWarning() << "Random exception, but we do not want to crash";
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << "Random exception, but we do not want to crash";
         return ResultIterator();
     }
 
@@ -194,7 +194,7 @@ ResultIterator ContactQuery::exec()
         iter.d->init(matches);
         return iter;
     } catch (const Xapian::Error &e) {
-        qWarning() << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
+        qCWarning(AKONADI_SEARCH_PIM_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
         return ResultIterator();
     }
 }
