@@ -35,7 +35,7 @@ public:
 
 private:
     class Private;
-    Private *d;
+    Private *const d;
 };
 }
 }
