@@ -22,15 +22,13 @@ public:
 
     void match(Plasma::RunnerContext &context) override;
     void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
-    QStringList categories() const override;
-    QIcon categoryIcon(const QString &category) const override;
 
 private:
     void queryContacts(Plasma::RunnerContext &context, const QString &queryString);
     void queryAutocompleter(Plasma::RunnerContext &context, const QString &queryString);
 
 private:
-    bool mQueryAutocompleter;
+    bool mQueryAutocompleter = true;
 };
 
 #endif // PIMCONTACTSRUNNER_H
