@@ -6,7 +6,6 @@
  */
 
 #include "pimcontactsrunnerconfig.h"
-#include <kconfigwidgets_version.h>
 #include <QCheckBox>
 #include <QVBoxLayout>
 #include <KLocalizedString>
@@ -21,9 +20,9 @@ K_PLUGIN_FACTORY(PIMContactsRunnerConfigFactory,
 PIMContactsRunnerConfig::PIMContactsRunnerConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
 {
-    QVBoxLayout *vbox = new QVBoxLayout(this);
+    auto *vbox = new QVBoxLayout(this);
 
-    mQueryCompletionCheckBox = new QCheckBox(i18n("Search in contacts indexed from sent and received emails too"));
+    mQueryCompletionCheckBox = new QCheckBox(i18n("Search in contacts indexed from sent and received emails too"), this);
     connect(mQueryCompletionCheckBox, &QCheckBox::stateChanged,
             this, &PIMContactsRunnerConfig::configChanged);
 
