@@ -21,11 +21,10 @@
 using namespace Akonadi::Search;
 
 XapianDatabase::XapianDatabase(const QString &path, bool writeOnly)
-    : m_db(nullptr)
-    , m_writeOnly(writeOnly)
+    : m_writeOnly(writeOnly)
 {
     QDir().mkpath(path);
-    m_path = path.toUtf8().constData();
+    m_path = path.toStdString();
 
     if (!writeOnly) {
         try {
